@@ -1,9 +1,10 @@
 package Neovim::Ext::Buffer;
-$Neovim::Ext::Buffer::VERSION = '0.02';
+$Neovim::Ext::Buffer::VERSION = '0.03';
 use strict;
 use warnings;
 use Tie::Array;
 use Neovim::Ext::Remote;
+use Neovim::Ext::Range;
 
 our @ISA = (qw/Neovim::Ext::Remote Tie::Array/);
 
@@ -118,13 +119,22 @@ sub mark
 }
 
 
+
+
+sub range
+{
+	my ($this, $start, $end) = @_;
+	return Neovim::Ext::Range->new ($this, $start, $end);
+}
+
+
 =head1 NAME
 
 Neovim::Ext::Buffer - Neovim Buffer class
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNPOSIS
 
@@ -151,6 +161,10 @@ A remote Nvim buffer. A C<Neovim::Ext::Buffer> instance is a tied array referenc
 
 Return the row and column for a named mark.
 
+=head2 range( $start, $end )
+
+Return a C<Neovim::Ext::Range> which represents part of the buffer.
+
 =head2 name( [$name] )
 
 Get or set buffer name.
