@@ -1,5 +1,5 @@
 package Neovim::Ext::Plugin;
-$Neovim::Ext::Plugin::VERSION = '0.02';
+$Neovim::Ext::Plugin::VERSION = '0.03';
 use strict;
 use warnings;
 use base qw/Class::Accessor/;
@@ -38,6 +38,11 @@ sub nvim_shutdown_hook :ATTR(CODE,BEGIN)
 	$package->_add_shutdown_hook ($sub, @$data);
 }
 
+sub nvim_rpc_export :ATTR(CODE,BEGIN)
+{
+	my ($package, $symbol, $sub, $attr, $data) = @_;
+	$package->_add_rpc_export ($sub, @$data);
+}
 
 
 sub get_specs
@@ -199,6 +204,33 @@ sub get_shutdown_hooks
 
 
 
+sub _add_rpc_export
+{
+	my ($package, $symbol, $name, %options) = @_;
+
+	$options{sync} //= 0;
+
+	no strict 'refs';
+	push @{$package.'::rpc_exports'},
+	{
+		type => 'rpc_export',
+		name => $name,
+		symbol => $symbol,
+		options => \%options,
+	};
+}
+
+
+
+sub get_rpc_exports
+{
+	my ($package) = @_;
+	no strict 'refs';
+	return @{$package.'::rpc_exports'};
+}
+
+
+
 sub new
 {
 	my ($this, $nvim, $host) = @_;
@@ -219,7 +251,7 @@ Neovim::Ext::Plugin - Neovim Plugin class
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -247,6 +279,10 @@ Subroutine attribute to export a subroutine as a Vim autocmd.
 
 Subroutine attribute to export a subroutine as a Vim function.
 
+=head2 nvim_rpc_export( )
+
+Subroutine attribute to export a subroutine as an RPC export.
+
 =head2 nvim_shutdown_hook( )
 
 Subroutine attribute to export a subroutine as a shutdown hook.
@@ -267,6 +303,10 @@ Get all exported autocmds for the plugin.
 
 Get all shutdown hooks for the plugin.
 
+=head2 get_rpc_exports( )
+
+Get all the RPC exports for the plugin.
+
 =head2 get_specs( )
 
 Get all specs for the plugin.
